@@ -13,7 +13,8 @@ vcov0	<- if(!is.null(vcov)) vcov else {
 kweights <- function(x, kernel = c("Truncated", "Bartlett", "Parzen",
                      "Tukey-Hanning", "Quadratic Spectral"), normalize = FALSE)
 {
-  kernel <- match.arg(kernel)
+  kernel <- match.arg(kernel,
+    c("Truncated", "Bartlett", "Parzen", "Tukey-Hanning", "Quadratic Spectral"))
   if(normalize) {
     ca <- switch(kernel,  
       "Truncated" = 2,
@@ -21,22 +22,38 @@ kweights <- function(x, kernel = c("Truncated", "Bartlett", "Parzen",
       "Parzen" = .539285,
       "Tukey-Hanning" = 3/4,
       "Quadratic Spectral" = 1)
-  } else ca <- 1
+  } else {
+    ca <- 1
+  }
 
   switch(kernel,  
-  "Truncated" = { ifelse(ca * x > 1, 0, 1) },
-  "Bartlett" = { ifelse(ca * x > 1, 0, 1 - abs(ca * x)) },
-  "Parzen" = { 
-    ifelse(ca * x > 1, 0, ifelse(ca * x < 0.5,
-      1 - 6 * (ca * x)^2 + 6 * abs(ca * x)^3, 2 * (1 - abs(ca * x))^3))
-  },
-  "Tukey-Hanning" = {
-    ifelse(ca * x > 1, 0, (1 + cos(pi * ca * x))/2)
-  },
-  "Quadratic Spectral" = {
-    y <- 6 * pi * x/5
-    ifelse(x < 1e-4, 1, 3 * (1/y)^2 * (sin(y)/y - cos(y)))
-  })
+    "Truncated" = {
+      ifelse(ca * abs(x) > 1, 0, 1)
+    },
+    "Bartlett" = {
+      ifelse(ca * abs(x) > 1, 0, 1 - abs(ca * x))
+    },
+    "Parzen" = { 
+      ifelse(ca * abs(x) > 1, 0, ifelse(ca * abs(x) < 0.5,
+        1 - 6 * (ca * x)^2 + 6 * abs(ca * x)^3,
+	2 * (1 - abs(ca * x))^3))
+    },
+    "Tukey-Hanning" = {
+      ifelse(ca * abs(x) > 1, 0, (1 + cos(pi * ca * x))/2)
+    },
+    "Quadratic Spectral" = {
+      qs <- function(x) {
+        y <- 6 * pi * x/5
+	3 * (1/y)^2 * (sin(y)/y - cos(y))
+      }
+      w <- qs(x)
+      if(length(ix <- which(abs(x) < 1e-3)) > 0L) {
+        cf <- 1e6 * log(qs(1e-3))
+        w[ix] <- exp(cf * x[ix]^2)
+      }
+      w
+    }
+  )
 }
 
 isoacf <- function(x, lagmax = NULL, weave1 = FALSE)
