@@ -35,7 +35,11 @@ meatCL <- function(x, cluster = NULL, type = NULL, cadjust = TRUE, multi0 = FALS
 
   ## collect 'cluster' variables in a data frame
   if(inherits(cluster, "formula")) {
-    cluster_tmp <- expand.model.frame(x, cluster, na.expand = FALSE)
+    cluster_tmp <- if("Formula" %in% loadedNamespaces()) { ## FIXME to suppress potential warnings due to | in Formula
+      suppressWarnings(expand.model.frame(x, cluster, na.expand = FALSE))
+    } else {
+      expand.model.frame(x, cluster, na.expand = FALSE)
+    }
     cluster <- model.frame(cluster, cluster_tmp, na.action = na.pass)
   } else {
     cluster <- as.data.frame(cluster)
